@@ -5,6 +5,6 @@
 
 ##-----------------------------------------------------------------------------
 fullfile <- function(...) {
-    file.path(...)
+    return(file.path(...))
 }
 
